<?php
/**
 * Implement theme metabox.
 *
 * @package Bizprime
 */
if (!function_exists('bizprime_add_theme_meta_box')) :

    /**
     * Add the Meta Box
     *
     * @since 1.0.0
     */
    function bizprime_add_theme_meta_box()
    {

        $screens = array('post', 'page');

        foreach ($screens as $screen) {
            add_meta_box(
                'bizprime-theme-settings',
                esc_html__('Single Page/Post Layout Settings', 'bizprime'),
                'bizprime_render_theme_settings_metabox',
                $screen,
                'normal', 
            	'high'

            );
        }

    }

endif;

add_action('add_meta_boxes', 'bizprime_add_theme_meta_box');


if ( ! function_exists( 'bizprime_render_theme_settings_metabox' ) ) :

	/**
	 * Render theme settings meta box.
	 *
	 * @since 1.0.0
	 */
	function bizprime_render_theme_settings_metabox( $post, $metabox ) {

		$post_id = $post->ID;
		$bizprime_post_meta_value = get_post_meta($post_id);

		// Meta box nonce for verification.
		wp_nonce_field( basename( __FILE__ ), 'bizprime_meta_box_nonce' );
		// Fetch Options list.
		$page_layout = get_post_meta($post_id,'bizprime-meta-select-layout',true);
		$image_layout = get_post_meta($post_id,'bizprime-meta-image-layout',true);
		$bizprime_meta_checkbox = get_post_meta($post_id,'bizprime-meta-checkbox',true);
	?>

	<div class="bizprime-tab-main">

        <div class="bizprime-metabox-tab">
            <ul>
                <li>
                    <a id="twp-tab-general" class="twp-tab-active" href="javascript:void(0)"><?php esc_html_e('Layout Settings', 'bizprime'); ?></a>
                </li>
            </ul>
        </div>

        <div class="bizprime-tab-content">
            
            <div id="twp-tab-general-content" class="bizprime-content-wrap bizprime-tab-content-active">

                <div class="bizprime-meta-panels">

                    <div class="bizprime-opt-wrap bizprime-checkbox-wrap">

                        <input id="bizprime-meta-checkbox" name="bizprime-meta-checkbox" type="checkbox" <?php if ( $bizprime_meta_checkbox ) { ?> checked="checked" <?php } ?> />

                        <label for="bizprime-meta-checkbox"><?php esc_html_e('Check To Enable Featured Image On Single Page', 'bizprime'); ?></label>
                    </div>

                    <div class="bizprime-opt-wrap bizprime-opt-wrap-alt">
						
						<label><?php esc_html_e('Single Page/Post Layout', 'bizprime'); ?></label>

	                     <select name="bizprime-meta-select-layout" id="bizprime-meta-select-layout">
				            <option value="right-sidebar" <?php selected('right-sidebar',$page_layout);?>>
				            	<?php _e( 'Content - Primary Sidebar', 'bizprime' )?>
				            </option>
				            <option value="left-sidebar" <?php selected('left-sidebar',$page_layout);?>>
				            	<?php _e( 'Primary Sidebar - Content', 'bizprime' )?>
				            </option>
				            <option value="no-sidebar" <?php selected('no-sidebar',$page_layout);?>>
				            	<?php _e( 'No Sidebar', 'bizprime' )?>
				            </option>
			            </select>

			        </div>

			        <div class="bizprime-opt-wrap bizprime-opt-wrap-alt">
						
						<label><?php esc_html_e('Single Page/Post Layout', 'bizprime'); ?></label>

	                     <select name="bizprime-meta-image-layout" id="bizprime-meta-image-layout">

	                     	<option value="full" <?php selected('full',$image_layout);  ?> > <?php esc_html_e( 'Full', 'bizprime' )?> </option>';
			            	<option value="right" <?php selected('right',$image_layout);  ?> ><?php esc_html_e( 'Right', 'bizprime' )?></option>';
			            	<option value="left" <?php selected('left',$image_layout);  ?> ><?php esc_html_e( 'Left', 'bizprime' )?></option>';
			            	<option value="no-image" <?php selected('no-image',$image_layout);  ?> ><?php esc_html_e( 'No Image', 'bizprime' )?></option>';

			            </select>

			        </div>

                </div>
            </div>

        </div>
    </div>

    <?php
	}

endif;



if ( ! function_exists( 'bizprime_save_theme_settings_meta' ) ) :

	/**
	 * Save theme settings meta box value.
	 *
	 * @since 1.0.0
	 *
	 * @param int     $post_id Post ID.
	 * @param WP_Post $post Post object.
	 */
	function bizprime_save_theme_settings_meta( $post_id, $post ) {

		// Verify nonce.
		if ( ! isset( $_POST['bizprime_meta_box_nonce'] ) || ! wp_verify_nonce( $_POST['bizprime_meta_box_nonce'], basename( __FILE__ ) ) ) {
			  return; }

		// Bail if auto save or revision.
		if ( defined( 'DOING_AUTOSAVE' ) || is_int( wp_is_post_revision( $post ) ) || is_int( wp_is_post_autosave( $post ) ) ) {
			return;
		}

		// Check the post being saved == the $post_id to prevent triggering this call for other save_post events.
		if ( empty( $_POST['post_ID'] ) || $_POST['post_ID'] != $post_id ) {
			return;
		}

		// Check permission.
		if ( 'page' === $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return; }
		} else if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		$bizprime_meta_checkbox =  isset( $_POST[ 'bizprime-meta-checkbox' ] ) ? esc_attr($_POST[ 'bizprime-meta-checkbox' ]) : '';
		update_post_meta($post_id, 'bizprime-meta-checkbox', sanitize_text_field($bizprime_meta_checkbox));

		$bizprime_meta_select_layout =  isset( $_POST[ 'bizprime-meta-select-layout' ] ) ? esc_attr($_POST[ 'bizprime-meta-select-layout' ]) : '';
		if(!empty($bizprime_meta_select_layout)){
			update_post_meta($post_id, 'bizprime-meta-select-layout', sanitize_text_field($bizprime_meta_select_layout));
		}

		$bizprime_meta_select_img_layout =  isset( $_POST[ 'bizprime-meta-image-layout' ] ) ? esc_attr($_POST[ 'bizprime-meta-image-layout' ]) : '';
		if(!empty($bizprime_meta_select_img_layout)){
			update_post_meta($post_id, 'bizprime-meta-image-layout', sanitize_text_field($bizprime_meta_select_img_layout));
		}
		
	}

endif;

add_action( 'save_post', 'bizprime_save_theme_settings_meta', 10, 3 );